<style>
    
.popup_share{    background: #fff none repeat scroll 0 0;
    border: 1px solid #bfbfc0;
    display: block;
    left: 50%;
    margin: 0 auto;
    margin-left: -126px;
    padding: 40px 20px 20px 20px;
    position: fixed;
    top: 50px;
    width: 260px;
    z-index: 9999999;
    height: 170px;}
    .popup_share a:hover{color:#2bbec6;}
.popup_share ul img{padding-bottom: 5px;width:25px;}
.popup_share li{float:left;text-align:center; width:65px; display: inline-block;}
.popup_share li a{font-size: 12px;}
.popup_share .s_share{clear:both;display: block; padding-top:15px;  position: relative;    width: 250px;}
.popup_share .s_window {
    background: #f8f8f8 none repeat scroll 0 0;
    border: 1px solid #d8d8d8;
    color: #686868;
    display: inline-block;
    font-size: 14px;
    height: 28px;
    padding-left: 10px;
    position: absolute;
    width: 174px;
}
.popup_share .s_close{position:absolute; right:25px; top:10px;}
.popup_share .s_src_sumit {
   background: #fff none repeat scroll 0 0;
    border: 1px solid #d8d8d8;
    height: 30px;
    line-height: 30px;
    overflow: visible;
    width: 65px;
    position: absolute;right:0;font-size: 12px;
}
</style>
<input type="hidden" name="share_content" id="share_content" value="<?php echo mb_substr(getMetaDescription($post->content), 0, 100)?>">
<input type="hidden" name="share_title" id="share_title" value="<?php echo str_replace('"', "'", $post->title)?>">
<input type="hidden" name="share_copy_url" id="share_copy_url" value="<?php echo getPathWithHost(uri_string())?>">
<input type="hidden" name="share_img_url" id="share_img_url" value="<?php echo imgSrc($post->mainImg)?>">
<div class="popup_share" id="share_box" style="display:none;">
    <p class="s_close"><a href="javascript:$('#share_box').hide();"><img src="/img/web/img_x.gif"></a></p>
    <ul>
        <li><a href="javascript:share_facebook();" class="fb-xfbml-parse-ignore"><img src="/img/web/img_fb.jpg"
                    alt="페이스북"><br>페이스북</a></li>
        <li><a href="javascript:share_twitter();"><img src="/img/web/img_tw.jpg" alt="트위터"><br>트위터</a></li>
        <li><a href="javascript:share_kakao();"><img src="/img/web/img_kk.jpg" alt="카카오톡 "><br>카카오톡</a></li>
        <li><a href="javascript:share_naver();"><img src="/img/web/img_na.jpg" alt="네이버"><br>네이버</a></li>
    </ul>
    <ul style="padding-top:10px; clear:both;">
        <li><a href="javascript:share_kakaostory();"><img src="/img/web/img_ks.jpg" alt="카카오스토리"><br>카카오스토리 </a></li>
        <li><a href="javascript:share_band();"><img src="/img/web/img_bd.jpg" alt="밴드"><br>밴드</a></li>
        <li><a href="javascript:bookmark()"><img src="/img/web/img_bm.jpg" alt="북마크"><br>북마크</a></li>
    </ul>
    <div class="s_share">
        <input type="text" class="s_window" id="copy_url" value="<?=CROSSMAP_URL?>">
        <button type="button" class="s_src_sumit" onclick="copy_url();">URL복사</button>
    </div>
</div>


<!-- 카카오톡 공유하기 -->
<script src="//developers.kakao.com/sdk/js/kakao.min.js"></script>



